summaryrefslogtreecommitdiffstats
path: root/src/logviewer.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/logviewer.h')
-rwxr-xr-xsrc/logviewer.h18
1 files changed, 10 insertions, 8 deletions
diff --git a/src/logviewer.h b/src/logviewer.h
index be3a8a3..094a1ff 100755
--- a/src/logviewer.h
+++ b/src/logviewer.h
@@ -20,26 +20,26 @@ class LogViewerItem : public KListViewItem
public:
/**
* Constructor
* @param parent The parent list view
* @param after The item, the new item should be placed after
* @param label1 The text for the first column
*/
- LogViewerItem( KListView* parent, LogViewerItem* after, QString label1 );
+ LogViewerItem( KListView* tqparent, LogViewerItem* after, TQString label1 );
/**
* Constructor
* @param parent The parent list view item
* @param after The item, the new item should be placed after
* @param label1 The text for the first column
*/
- LogViewerItem( LogViewerItem* parent, LogViewerItem* after, QString label1 );
+ LogViewerItem( LogViewerItem* tqparent, LogViewerItem* after, TQString label1 );
/**
* Destructor
*/
virtual ~LogViewerItem();
- virtual void paintCell( QPainter* p, const QColorGroup& cg, int column, int width, int alignment );
+ virtual void paintCell( TQPainter* p, const TQColorGroup& cg, int column, int width, int tqalignment );
LogViewerItem* nextSibling() const { return static_cast<LogViewerItem*>( KListViewItem::nextSibling() ); }
LogViewerItem* firstChild() const { return static_cast<LogViewerItem*>( KListViewItem::firstChild() ); }
@@ -56,13 +56,14 @@ public:
class LogViewerList : public KListView
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor
* @param parent The parent widget
* @param name The name of the file list
*/
- LogViewerList( QWidget * parent = 0, const char* name = 0 );
+ LogViewerList( TQWidget * tqparent = 0, const char* name = 0 );
/**
* Destructor
@@ -81,11 +82,12 @@ public:
class LogViewer : public KDialog
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Default Constructor
*/
- LogViewer( Logger* _logger, QWidget* parent=0, const char* name = 0, bool modal = true, WFlags f = 0 );
+ LogViewer( Logger* _logger, TQWidget* tqparent=0, const char* name = 0, bool modal = true, WFlags f = 0 );
/**
* Default Destructor
@@ -20,26 +20,26 @@ class LogViewerItem : public KListViewItem
/**
* Constructor
- * @param parent The parent list view
+ * @param tqparent The tqparent list view
* @param after The item, the new item should be placed after
* @param label1 The text for the first column
@@ -20,26 +20,26 @@ class LogViewerItem : public KListViewItem
/**
* Constructor
- * @param parent The parent list view item
+ * @param tqparent The tqparent list view item
* @param after The item, the new item should be placed after
* @param label1 The text for the first column
@@ -56,13 +56,14 @@ public:
/**
* Constructor
- * @param parent The parent widget
+ * @param tqparent The tqparent widget
* @param name The name of the file list
*/